@@ -1,9 +1,9 @@
 #! /bin/sh
-exec guile -s "$0" "$@"
+exec guile-gtk -s $0 $*
 !#
 ;; Time-stamp: <1998-03-15 21:18:16 szi>
 ;;
-;; Copyright (C) 1997, 1998, 1999, 2003 Free Software Foundation, Inc.
+;; Copyright (C) 1997, 1998 Marius Vollmer
 ;; 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -187,9 +187,6 @@ exec guile -s "$0" "$@"
 (define-module (calc)
   :use-module (gtk gtk))
 
-(if (not (defined? 'gtk-scrolled-window-add-with-viewport))
-    (define gtk-scrolled-window-add-with-viewport gtk-container-add))
-
 ;; First some utility functions.  The first saves us from writing a
 ;; million times "gtk-widget-show".  It is like gtk-widget-show but
 ;; takes any number of widgets and shows them all.
@@ -224,7 +221,7 @@ exec guile -s "$0" "$@"
         ;; arbitrary values, with the top of the stack in the first
         ;; element.  It starts out empty.
 	(stack '()))
-  
+
     ;; Some handy operations to work on the stack.  I think you can
     ;; figure them out.
     (define (push val) (set! stack (cons val stack)))
@@ -280,7 +277,7 @@ exec guile -s "$0" "$@"
 	  ;; changed, which leads to visible flicker.
 	  (cond ((not (string=? last-text text))
 		 (set! last-text text)
-		 (gtk-label-set-text echo text))))))
+		 (gtk-label-set echo text))))))
 
     ;; Construct a concise error message out of KEY and ARGS.  For now
     ;; we just return the KEY as a string and print a more verbose
@@ -298,18 +295,11 @@ exec guile -s "$0" "$@"
     ;; entry is empty.  It defaults to `#t'.  The entry is cleared
     ;; after pushing the value.
     (define (activate-entry . opt-dup)
-      (define (read-all port)
-	(let loop ((res '())
-		   (val (read port)))
-	  (if (eof-object? val)
-	      (reverse! res)
-	      (loop (cons val res) (read port)))))
-      (let ((vals (call-with-input-string (gtk-entry-get-text entry)
-					  read-all)))
-	(if (null? vals)
+      (let ((val (call-with-input-string (gtk-entry-get-text entry) read)))
+	(if (eof-object? val)
 	    (if (and (or (null? opt-dup) (car opt-dup)) (not (null? stack)))
 		(push (car stack)))
-	    (for-each push vals))
+	    (push val))
 	(redisplay)
 	(gtk-entry-set-text entry "")
 	(set-echo "")))
@@ -386,7 +376,7 @@ exec guile -s "$0" "$@"
     ;; you would write it in C.
     (gtk-window-set-title window "Calc")
     (gtk-scrolled-window-set-policy scrolled-win 'automatic 'always)
-    (gtk-scrolled-window-add-with-viewport scrolled-win list-widget)
+    (gtk-container-add scrolled-win list-widget)
     (gtk-misc-set-alignment echo 0.0 0.5)
     (gtk-widget-set-usize scrolled-win 200 120)
 
